==> kipi-plugins-trinity-3.5.13.2.tar.xz: kipi-plugins-trinity-3.5.13.2/kipi-plugins/batchprocessimages/resizeimagesdialog.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2004-10-01
 * Description : a kipi plugin to batch process images
 *
 * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef RESIZEIMAGESDIALOG_H
#define RESIZEIMAGESDIALOG_H

// Local includes

#include "kpaboutdata.h"
#include "batchprocessimagesdialog.h"

namespace KIPIBatchProcessImagesPlugin
{

class BatchProcessImagesItem;

class ResizeImagesDialog : public BatchProcessImagesDialog
{
Q_OBJECT
  TQ_OBJECT

 public:
 
   ResizeImagesDialog( KURL::List images, KIPI::Interface* interface, TQWidget *parent=0 );
   ~ResizeImagesDialog();

 private slots:
 
   void slotHelp(void);
   void slotOptionsClicked(void);

 protected:
 
   TQString                m_resizeFilter;
   TQString                m_paperSize;
   TQString                m_printDpi;

   TQColor                 m_backgroundColor;
   TQColor                 m_bgColor;

   bool                   m_customSettings;

   int                    m_customXSize;
   int                    m_customYSize;
   int                    m_marging;
   int                    m_customDpi;
   int                    m_size;
   int                    m_xPixels;
   int                    m_yPixels;
   int                    m_Width;
   int                    m_Height;
   int                    m_Border;
   int                    m_fixedWidth;
   int                    m_fixedHeight;
   int			  m_quality;

   TQString makeProcess(KProcess* proc, BatchProcessImagesItem *item,
                       const TQString& albumDest, bool previewMode);

   void readSettings(void);
   void saveSettings(void);
   bool prepareStartProcess(BatchProcessImagesItem *item,
                            const TQString& albumDest);

   bool ResizeImage( int &w, int &h, int SizeFactor);

 private:

 KIPIPlugins::KPAboutData   *m_about;
};

}  // NameSpace KIPIBatchProcessImagesPlugin

#endif  // RESIZEIMAGESDIALOG_H

==> kipi-plugins-trinity-14.0.8.tar.xz: kipi-plugins-trinity-14.0.8/kipi-plugins/batchprocessimages/resizeimagesdialog.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2004-10-01
 * Description : a kipi plugin to batch process images
 *
 * Copyright (C) 2004-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef RESIZEIMAGESDIALOG_H
#define RESIZEIMAGESDIALOG_H

// Local includes

#include "kpaboutdata.h"
#include "batchprocessimagesdialog.h"

namespace KIPIBatchProcessImagesPlugin
{

class BatchProcessImagesItem;

class ResizeImagesDialog : public BatchProcessImagesDialog
{
Q_OBJECT
  

 public:
 
   ResizeImagesDialog( KURL::List images, KIPI::Interface* interface, TQWidget *parent=0 );
   ~ResizeImagesDialog();

 private slots:
 
   void slotHelp(void);
   void slotOptionsClicked(void);

 protected:
 
   TQString                m_resizeFilter;
   TQString                m_paperSize;
   TQString                m_printDpi;

   TQColor                 m_backgroundColor;
   TQColor                 m_bgColor;

   bool                   m_customSettings;

   int                    m_customXSize;
   int                    m_customYSize;
   int                    m_marging;
   int                    m_customDpi;
   int                    m_size;
   int                    m_xPixels;
   int                    m_yPixels;
   int                    m_Width;
   int                    m_Height;
   int                    m_Border;
   int                    m_fixedWidth;
   int                    m_fixedHeight;
   int			  m_quality;

   TQString makeProcess(TDEProcess* proc, BatchProcessImagesItem *item,
                       const TQString& albumDest, bool previewMode);

   void readSettings(void);
   void saveSettings(void);
   bool prepareStartProcess(BatchProcessImagesItem *item,
                            const TQString& albumDest);

   bool ResizeImage( int &w, int &h, int SizeFactor);

 private:

 KIPIPlugins::KPAboutData   *m_about;
};

}  // NameSpace KIPIBatchProcessImagesPlugin

#endif  // RESIZEIMAGESDIALOG_H
